import React from 'react';
import ReactDOM from 'react-dom/client';

const App = () => {
  const profile = {
    name: "Иван Иванов",
    role: "Младший системный администратор",
    experience: "2 года опыта",
    about:
      "Прошёл путь от технической поддержки до младшего системного администратора. Увлекаюсь автоматизацией процессов, изучением новых технологий и решением нестандартных задач.",
    hobbies: ["Автоматизация", "Linux", "Шахматы", "Python"],
    skills: [
      { name: "Bash", level: "Pro" },
      { name: "PowerShell", level: "Pro" },
      { name: "Docker", level: "Mid" },
      { name: "Ansible", level: "Mid" },
      { name: "Git", level: "Pro" },
      { name: "SSH", level: "Pro" },
      { name: "Linux Server", level: "Pro" },
      { name: "Windows Server", level: "Mid" },
      { name: "CI/CD", level: "Mid" },
      { name: "SQL", level: "Low" },
    ],
    email: "ivan@example.com",
    telegram: "@ivanov",
    avatar: "https://placehold.co/150x150 "
  };

  const careerPath = [
    { year: '2021', title: 'Техническая поддержка', description: 'Первые шаги в IT, помощь пользователям' },
    { year: '2022', title: 'Самообразование', description: 'Изучил Linux, Bash, PowerShell' },
    { year: '2023', title: 'Junior SysAdmin', description: 'Работа в компании, автоматизация через скрипты' },
    { year: '2024–наст. время', title: 'Продолжаю развитие', description: 'Осваиваю Docker, Ansible, CI/CD' }
  ];

  return (
    <div className="bg-slate-900 min-h-screen text-gray-200 font-sans py-12 px-4">
      {/* Main Card */}
      <div className="max-w-xl mx-auto bg-slate-800 rounded-lg shadow-xl p-8 mb-12 transition-transform duration-300 transform hover:scale-105 border border-slate-700">
        <img src={profile.avatar} alt="Аватар" className="w-32 h-32 object-cover rounded-full mx-auto border-4 border-indigo-500" />
        <h1 className="text-3xl font-bold text-center mt-4 text-white">{profile.name}</h1>
        <p className="text-lg text-center text-blue-300">{profile.role}</p>
        <p className="text-sm text-center text-purple-300 mt-1">{profile.experience}</p>

        <div className="mt-6">
          <h2 className="font-semibold text-indigo-300">Обо мне:</h2>
          <p className="mt-2 text-sm text-gray-300">{profile.about}</p>
        </div>

        <div className="mt-6">
          <h2 className="font-semibold text-indigo-300">Хобби:</h2>
          <ul className="flex flex-wrap gap-2 mt-2 justify-center">
            {profile.hobbies.map((hobby, index) => (
              <li key={index} className="bg-slate-700 text-indigo-200 px-3 py-1 rounded-full text-sm border border-slate-600">
                {hobby}
              </li>
            ))}
          </ul>
        </div>

        <div className="mt-6">
          <h2 className="font-semibold text-indigo-300">Навыки:</h2>
          <ul className="flex flex-wrap gap-2 mt-2 justify-center">
            {profile.skills.map((skill, index) => {
              let levelColor = '';
              switch (skill.level) {
                case 'Low':
                  levelColor = 'bg-red-900 text-red-200 border-red-700';
                  break;
                case 'Mid':
                  levelColor = 'bg-yellow-900 text-yellow-200 border-yellow-700';
                  break;
                case 'Pro':
                  levelColor = 'bg-green-900 text-green-200 border-green-700';
                  break;
                default:
                  levelColor = 'bg-slate-700 text-gray-200 border-slate-600';
              }

              return (
                <li key={index} className={`px-3 py-1 rounded-full text-sm border ${levelColor} flex items-center space-x-2`}>
                  <span>{skill.name}</span>
                  <span className="text-xs px-2 py-0.5 rounded-full bg-black bg-opacity-50">{skill.level}</span>
                </li>
              );
            })}
          </ul>
        </div>
      </div>

      {/* Career Timeline */}
      <div className="max-w-xl mx-auto">
        <h2 className="text-2xl font-bold mb-6 text-center text-indigo-300">Карьера</h2>
        <div className="relative border-l-2 border-indigo-500 pl-6">
          {careerPath.map((item, index) => (
            <div key={index} className="mb-8 ml-2 relative group">
              <span className="absolute -left-3 top-1 w-3 h-3 bg-indigo-400 rounded-full"></span>
              <time className="text-sm font-semibold text-indigo-300">{item.year}</time>
              <h3 className="text-lg font-medium text-white group-hover:text-indigo-300 transition">{item.title}</h3>
              <p className="text-gray-400">{item.description}</p>
            </div>
          ))}
        </div>
      </div>

      {/* Footer / Contact */}
      <footer className="max-w-xl mx-auto mt-16 text-center text-gray-400">
        <h3 className="text-lg font-semibold text-indigo-300 mb-2">Связь со мной</h3>
        <p className="text-sm mb-4">Если есть вопросы или предложения — напиши мне.</p>
        <div className="flex justify-center space-x-4">
          <a href={`mailto:${profile.email}`} className="text-blue-400 hover:text-blue-200 transition">📧 Email</a>
          <a href={`https://t.me/ ${profile.telegram.replace('@', '')}`} target="_blank" rel="noopener noreferrer" className="text-blue-400 hover:text-blue-200 transition">💬 Telegram</a>
        </div>
        <p className="mt-6 text-xs">&copy; {new Date().getFullYear()} Иван Иванов. Все права защищены.</p>
      </footer>

      {/* Interactive Terminal Block */}
      <div className="max-w-xl mx-auto mt-16">
        <TerminalSevenLines />
      </div>
    </div>
  );
};

function TerminalSevenLines() {
  const [lines, setLines] = React.useState([
    'echo "Добро пожаловать!"',
    'sleep 1',
    'echo "Введите команду для продолжения:"',
    'echo "help | coffee | sudo --me"',
    '$ '
  ]);

  const [isTyping, setIsTyping] = React.useState(false);

  const commands = {
    help: 'echo "Доступные команды: help, coffee, sudo --me, man life, grep problems"',
    coffee: 'echo "Starting coffee.sh..." && sleep 1 && echo "Error: coffee not found"',
    'sudo --me': 'echo "sudo: неизвестная команда. Но ты уже почти root."',
    'man life': 'echo "life(1) — твой главный процесс. Запущен как PID 1."',
    'grep problems /dev/null': 'echo "grep: /dev/null: Нет проблем найдено (пока)"',
    ls: 'echo "resume.pdf  projects  notes.txt"',
    exit: 'echo "Выход? Не сейчас."'
  };

  const MAX_LINES = 7;

  const addLine = (line) => {
    setLines((prev) => {
      const updated = [...prev.slice(-MAX_LINES + 1), line];
      return updated;
    });
  };

  const simulateTypingLine = (line, callback) => {
    setIsTyping(true);
    let i = 0;
    const interval = setInterval(() => {
      if (i <= line.length) {
        setLines((prev) => {
          const last = prev[prev.length - 1];
          if (last.startsWith('$')) {
            return [...prev.slice(0, -1), `$ ${line.slice(0, i)}`];
          } else {
            return [...prev, `$ ${line.slice(0, i)}`];
          }
        });
        i++;
      } else {
        clearInterval(interval);
        setIsTyping(false);
        setTimeout(callback, 500);
      }
    }, 30);
  };

  const simulateOutput = (output) => {
    const outputLines = output.split('\n');
    let currentLine = 0;

    const printNextLine = () => {
      if (currentLine < outputLines.length) {
        let i = 0;
        const line = outputLines[currentLine];

        const interval = setInterval(() => {
          if (i <= line.length) {
            setLines((prev) => {
              const last = prev[prev.length - 1];
              if (last.startsWith('$')) {
                return [...prev.slice(0, -1), line.slice(0, i)];
              } else {
                return [...prev, line.slice(0, i)];
              }
            });
            i++;
          } else {
            clearInterval(interval);
            currentLine++;
            setTimeout(printNextLine, 300);
          }
        }, 20);
      } else {
        addLine('$ ');
        setIsTyping(false);
      }
    };

    printNextLine();
  };

  const handleTerminalClick = () => {
    if (isTyping) return;

    const availableCommands = Object.keys(commands);
    const command = availableCommands[Math.floor(Math.random() * availableCommands.length)];

    // Начинаем ввод команды
    simulateTypingLine(command, () => {
      setTimeout(() => {
        const response = commands[command];
        addLine(response.split('\n')[0]);
        simulateOutput(response);
      }, 300);
    });
  };

  return (
    <div onClick={handleTerminalClick} className="bg-black text-green-400 font-mono text-sm p-4 rounded-lg border border-green-700 shadow-lg cursor-text h-40 overflow-hidden leading-relaxed">
      <div className="h-full flex flex-col justify-end">
        {lines.map((line, i) => (
          <div key={i}>{line}</div>
        ))}
        <span className="animate-pulse">|</span>
      </div>
    </div>
  );
};

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(<App />);